pub struct EqPerfDomain {
pub id: usize,
pub perf_doms: Vec<Arc<PerfDomain>>,
pub span: Cpumask,
pub perf_table: BTreeMap<usize, Arc<PerfState>>,
}Expand description
A set of performance domains sharing an identical performance table.
How many CPUs a performance domain covers is processor-specific: it can be a
cluster, a core, or a single CPU. Intel hybrid processors, for instance, have
one performance domain per CPU, so all the P-cores (or all the E-cores) are
represented by separate performance domains even though they are identical.
Such domains are interchangeable, so a search for the cheapest set of CPUs
can consider how many CPUs to take from an equivalence performance domain
rather than which performance domains to activate, reducing the search space
from 2^nr_perf_doms to prod(weight_i + 1).
Fields
id: usizeMonotonically increasing unique id.
perf_doms: Vec<Arc<PerfDomain>>Member performance domains in ascending domain id order.
span: CpumaskCpumask of all CPUs in this equivalence performance domain.
perf_table: BTreeMap<usize, Arc<PerfState>>Table of performance states indexed by performance, shared by all member performance domains.